@@ -129,8 +129,14 @@ class Parser:
     def p_term_topic_equal_literal(self, p):
         'term : TOPIC EQUAL literal'
         lhs, rhs = p[1], p[3]
-        conv = float if type(rhs) is float else str
-        p[0] = self.Expr(set([lhs]), lambda s: conv(s[lhs]) == rhs)
+        cast = type(rhs)
+        p[0] = self.Expr(set([lhs]), lambda s: cast(s[lhs]) == rhs)
+        
+    def p_term_topic_not_equal_literal(self, p):
+        'term : TOPIC NOT_EQUAL literal'
+        lhs, rhs = p[1], p[3]
+        cast = type(rhs)
+        p[0] = self.Expr(set([lhs]), lambda s: cast(s[lhs]) != rhs)
         
     def p_term_topic_regex_match_string(self, p):
         'term : TOPIC REGEX_MATCH STRING'
@@ -138,12 +144,6 @@ class Parser:
         pattern = re.compile(rhs)
         p[0] = self.Expr(set([lhs]), lambda s: pattern.search(str(s[lhs])) is not None)
         
-    def p_term_topic_not_equal_literal(self, p):
-        'term : TOPIC NOT_EQUAL literal'
-        lhs, rhs = p[1], p[3]
-        conv = float if type(rhs) is float else str
-        p[0] = self.Expr(set([lhs]), lambda s: conv(s[lhs]) != rhs)
-        
     def p_literal(self, p):
         '''literal : NUMBER
                    | STRING'''
