@@ -61,21 +61,21 @@ class StateAwareMixin:
                 method(self)
 
 
-    def publish(self, topic, new_state, **kw):
+    def publish(self, topic, payload=None, **kw):
         'Avoid redundant updates'
         old_state = self.current_state.get(topic)
         if old_state is not None:
-            if old_state == new_state: return
+            if old_state == payload: return
 
             cast = type(old_state)
             try:
-                if cast(new_state) == old_state: return
+                if cast(payload) == old_state: return
             except: pass
-        return super().publish(topic, new_state, **kw)
+        return super().publish(topic, payload, **kw)
 
 
 def conditional(expression):
-    ''' The decorated status handler method is invoked
+    ''' Decorated a status handler method which is invoked
         with the value of the expression
         whenever the expression depends on an updated topic.
         For the expression grammar, see the docstrings in `expr.py`.
@@ -97,7 +97,7 @@ def conditional(expression):
 
 
 def when(expression):
-    ''' The decorated status handler method is invoked
+    ''' Decorate a status handler method which is invoked
         when the expression depends on an updated topic
         and when it evaluates to `True`.
         For the expression grammar, see the docstrings in `expr.py`.
